summaryrefslogtreecommitdiffstats
path: root/lib/widgets/propeditor/qeditlistbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/widgets/propeditor/qeditlistbox.h')
-rw-r--r--lib/widgets/propeditor/qeditlistbox.h92
1 files changed, 46 insertions, 46 deletions
diff --git a/lib/widgets/propeditor/qeditlistbox.h b/lib/widgets/propeditor/qeditlistbox.h
index 93bf8bf3..245f8b57 100644
--- a/lib/widgets/propeditor/qeditlistbox.h
+++ b/lib/widgets/propeditor/qeditlistbox.h
@@ -20,8 +20,8 @@
#ifndef QEDITLISTBOX_H
#define QEDITLISTBOX_H
-#include <qgroupbox.h>
-#include <qlistbox.h>
+#include <tqgroupbox.h>
+#include <tqlistbox.h>
class KLineEdit;
class QComboBox;
@@ -46,7 +46,7 @@ class QEditListBox : public QGroupBox
{
Q_OBJECT
- Q_PROPERTY( QStringList items READ items WRITE setItems )
+ Q_PROPERTY( TQStringList items READ items WRITE setItems )
public:
// @since 3.1
@@ -56,19 +56,19 @@ public:
CustomEditor()
: m_representationWidget( 0L ),
m_lineEdit( 0L ) {}
- CustomEditor( QWidget *repWidget, KLineEdit *edit )
+ CustomEditor( TQWidget *repWidget, KLineEdit *edit )
: m_representationWidget( repWidget ),
m_lineEdit( edit ) {}
- CustomEditor( QComboBox *combo );
+ CustomEditor( TQComboBox *combo );
- void setRepresentationWidget( QWidget *repWidget ) {
+ void setRepresentationWidget( TQWidget *repWidget ) {
m_representationWidget = repWidget;
}
void setLineEdit( KLineEdit *edit ) {
m_lineEdit = edit;
}
- virtual QWidget *representationWidget() const {
+ virtual TQWidget *representationWidget() const {
return m_representationWidget;
}
virtual KLineEdit *lineEdit() const {
@@ -76,7 +76,7 @@ public:
}
protected:
- QWidget *m_representationWidget;
+ TQWidget *m_representationWidget;
KLineEdit *m_lineEdit;
};
@@ -100,7 +100,7 @@ public:
* it will be checked if you press the Add-button. It is not
* possible to enter items twice into the listbox.
*/
- QEditListBox(QWidget *parent = 0, const char *name = 0,
+ QEditListBox(TQWidget *parent = 0, const char *name = 0,
bool checkAtEntering=false, int buttons = All );
/**
* Create an editable listbox.
@@ -108,33 +108,33 @@ public:
* The same as the other constructor, additionally it takes
* @p title, which will be the title of the frame around the listbox.
*/
- QEditListBox(const QString& title, QWidget *parent = 0,
+ QEditListBox(const TQString& title, TQWidget *parent = 0,
const char *name = 0, bool checkAtEntering=false,
int buttons = All );
/**
* Another constructor, which allows to use a custom editing widget
* instead of the standard QLineEdit widget. E.g. you can use a
* KURLRequester or a QComboBox as input widget. The custom
* editor must consist of a lineedit and optionally another widget that
* is used as representation. A QComboBox or a KURLRequester have a
* QLineEdit as child-widget for example, so the QComboBox is used as
* the representation widget.
*
* @see KURLRequester::customEditor()
* @since 3.1
*/
- QEditListBox( const QString& title,
+ QEditListBox( const TQString& title,
const CustomEditor &customEditor,
- QWidget *parent = 0, const char *name = 0,
+ TQWidget *parent = 0, const char *name = 0,
bool checkAtEntering = false, int buttons = All );
virtual ~QEditListBox();
/**
* Return a pointer to the embedded QListBox.
*/
- QListBox* listBox() const { return m_listBox; }
+ TQListBox* listBox() const { return m_listBox; }
/**
* Return a pointer to the embedded KLineEdit.
*/
@@ -142,72 +142,72 @@ public:
/**
* Return a pointer to the Add button
*/
- QPushButton* addButton() const { return servNewButton; }
+ TQPushButton* addButton() const { return servNewButton; }
/**
* Return a pointer to the Remove button
*/
- QPushButton* removeButton() const { return servRemoveButton; }
+ TQPushButton* removeButton() const { return servRemoveButton; }
/**
* Return a pointer to the Up button
*/
- QPushButton* upButton() const { return servUpButton; }
+ TQPushButton* upButton() const { return servUpButton; }
/**
* Return a pointer to the Down button
*/
- QPushButton* downButton() const { return servDownButton; }
+ TQPushButton* downButton() const { return servDownButton; }
/**
- * See QListBox::count()
+ * See TQListBox::count()
*/
int count() const { return int(m_listBox->count()); }
/**
- * See QListBox::insertStringList()
+ * See TQListBox::insertStringList()
*/
- void insertStringList(const QStringList& list, int index=-1);
+ void insertStringList(const TQStringList& list, int index=-1);
/**
- * See QListBox::insertStringList()
+ * See TQListBox::insertStringList()
*/
- void insertStrList(const QStrList* list, int index=-1);
+ void insertStrList(const TQStrList* list, int index=-1);
/**
- * See QListBox::insertStrList()
+ * See TQListBox::insertStrList()
*/
- void insertStrList(const QStrList& list, int index=-1);
+ void insertStrList(const TQStrList& list, int index=-1);
/**
- * See QListBox::insertStrList()
+ * See TQListBox::insertStrList()
*/
void insertStrList(const char ** list, int numStrings=-1, int index=-1);
/**
- * See QListBox::insertItem()
+ * See TQListBox::insertItem()
*/
- void insertItem(const QString& text, int index=-1) {m_listBox->insertItem(text,index);}
+ void insertItem(const TQString& text, int index=-1) {m_listBox->insertItem(text,index);}
/**
* Clears both the listbox and the line edit.
*/
void clear();
/**
- * See QListBox::text()
+ * See TQListBox::text()
*/
- QString text(int index) const { return m_listBox->text(index); }
+ TQString text(int index) const { return m_listBox->text(index); }
/**
- * See QListBox::currentItem()
+ * See TQListBox::currentItem()
*/
int currentItem() const;
/**
- * See QListBox::currentText()
+ * See TQListBox::currentText()
*/
- QString currentText() const { return m_listBox->currentText(); }
+ TQString currentText() const { return m_listBox->currentText(); }
/**
* @returns a stringlist of all items in the listbox
*/
- QStringList items() const;
+ TQStringList items() const;
/**
* Clears the listbox and sets the contents to @p items
*
* @since 3.4
*/
- void setItems(const QStringList& items);
+ void setItems(const TQStringList& items);
signals:
void changed();
@@ -217,14 +217,14 @@ public:
* the parameter is the added string.
* @since 3.2
*/
- void added( const QString & text );
+ void added( const TQString & text );
/**
* This signal is emitted when the user removes a string from the list,
* the parameter is the removed string.
* @since 3.2
*/
- void removed( const QString & text );
+ void removed( const TQString & text );
protected slots:
//the names should be self-explaining
@@ -233,17 +233,17 @@ public:
void addItem();
void removeItem();
void enableMoveButtons(int index);
- void typedSomething(const QString& text);
+ void typedSomething(const TQString& text);
private:
- QListBox *m_listBox;
- QPushButton *servUpButton, *servDownButton;
- QPushButton *servNewButton, *servRemoveButton;
+ TQListBox *m_listBox;
+ TQPushButton *servUpButton, *servDownButton;
+ TQPushButton *servNewButton, *servRemoveButton;
KLineEdit *m_lineEdit;
//this is called in both ctors, to avoid code duplication
void init( bool checkAtEntering, int buttons,
- QWidget *representationWidget = 0L );
+ TQWidget *representationWidget = 0L );
protected:
virtual void virtual_hook( int id, void* data );
@@ -108,33 +108,33 @@ public:
/**
* Another constructor, which allows to use a custom editing widget
- * instead of the standard QLineEdit widget. E.g. you can use a
- * KURLRequester or a QComboBox as input widget. The custom
+ * instead of the standard TQLineEdit widget. E.g. you can use a
+ * KURLRequester or a TQComboBox as input widget. The custom
* editor must consist of a lineedit and optionally another widget that
@@ -108,33 +108,33 @@ public:
* editor must consist of a lineedit and optionally another widget that
- * is used as representation. A QComboBox or a KURLRequester have a
- * QLineEdit as child-widget for example, so the QComboBox is used as
+ * is used as representation. A TQComboBox or a KURLRequester have a
+ * TQLineEdit as child-widget for example, so the TQComboBox is used as
* the representation widget.
*
@@ -108,33 +108,33 @@ public:
virtual ~QEditListBox();
/**
- * Return a pointer to the embedded QListBox.
+ * Return a pointer to the embedded TQListBox.
*/